@@ -2,8 +2,8 @@
 from sqlalchemy import Column, Float, Integer, String
 from sqlalchemy.ext.declarative import declarative_base
 
-from zvdata import Mixin
-from zvdata.contract import register_schema
+from zvt.contract import Mixin
+from zvt.contract.register import register_schema
 
 Stock1wkMaStateStatsBase = declarative_base()
 
